<?php
if ( ! class_exists( 'IPTrank_AdminTableGroup' )) {

    /**
     * Class for display table of smart pop up
     */
    class IPTrank_AdminTableGroup extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns                  = array();
            $posts_columns['name']          = __( 'Name', 'iptrank' );
            $posts_columns['description']   = __( 'Description', 'iptrank' );
            $posts_columns['actions']       = __( 'Actions', 'iptrank' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'name'   => 'name'
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wp_query, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $per_page = $this->get_items_per_page( 'edit_iptrank-list_per_page' );
            $per_page = apply_filters( 'edit_posts_per_page', $per_page, 'iptrank-list' );
            
            $model = new IPTrank_Model();
            $this->items = $model->get_groups( $per_page, $page );

            $total_items = $model->get_found_item();
            $total_pages = ceil( $total_items / $per_page );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page'    => $per_page
            ) );
        }

        /**
         * Get column name
         *
         * @param object $item
         * @return void
         */
        public function column_name( $item ) 
        {
            $title = $item->group_name;
            $link  = admin_url() . 'admin.php?page=iptrank_group&action=edit&id='.$item->group_id;
            return '<strong><a class="row-title" href="' . $link . '">' . $title . '</a></strong>';
        }

        /**
         * Get column description
         *
         * @param object $item
         * @return void
         */
        public function column_description( $item ) 
        {
            $slug = $item->group_info;
            return $slug;
        }

        /**
         * Get column actions
         *
         * @param object $item
         * @return void
         */
        public function column_actions( $item ) 
        {
            $linkEdit = admin_url() . 'admin.php?page=iptrank_group&action=edit&id='.$item->group_id;
            $linkDel  = '#toDelete_'.$item->group_id;
            $actions  = '<div class="iptrank-actions">
                            <a class="iptrank-group-edit ipadm-btn ipadm-btn-primary ipadm-btn-small" href="' . $linkEdit . '">' . 
                                '<i class="faip fa-pencil"></i><span class="ipadm-separator"></span>' .
                                __( 'Edit' ) . '
                            </a>
                            <a class="iptrank-group-delete ipadm-btn ipadm-btn-danger ipadm-btn-small" href="' . $linkDel . '">' .
                                '<i class="faip fa-trash-o"></i><span class="ipadm-separator"></span>' . 
                                __( 'Delete' ) . '
                            </a>
                        </div>';
            
            return $actions;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>