<?php
if ( ! class_exists( 'IPTrank_AdminTable_Log' )) {

    /**
     * Class for display log table
     */
    class IPTrank_AdminTable_Log extends WP_List_Table
    {
        /**
         * Get a list of columns. The format is:
         * 'internal-name' => 'Title'
         *
         * @return array
         */
        public function get_columns() 
        {
            $posts_columns                  = array();
            $posts_columns['no']            = __( 'No', 'iptrank' );
            $posts_columns['date']          = __( 'Date', 'iptrank' );
            $posts_columns['action']        = __( 'Type of Action', 'iptrank' );
            $posts_columns['description']   = __( 'Description', 'iptrank' );
            return $posts_columns;
        }


        /**
         * Get a list of sortable columns. The format is:
         * 'internal-name' => 'orderby'
         * or
         * 'internal-name' => array( 'orderby', true )
         *
         * The second format will make the initial sorting order be descending
         *
         * @return array
         */
        public function get_sortable_columns() 
        {
            return array(
                'date'   => 'date'
            );
        }

        /**
         * Get a list of all, hidden and sortable columns, with filter applied
         *
         * @return array
         */
        public function get_column_info() 
        {
            $columns  = $this->get_columns();
            $hidden   = array();
            $sortable = array();
            $this->_column_headers = array( $columns, $hidden, $sortable );
            return $this->_column_headers;
        }

        /**
         * Prepares the list of items for displaying.
         * @uses WP_List_Table::set_pagination_args()
         *
         */
        public function prepare_items() 
        {
            global $wp_query, $per_page;
            
            $page = 1;
            if ( ! empty( $_GET['paged'] )) {
                $page = absint( $_GET['paged'] );
            }
            $per_page   = 40;
            $date_start = '';
            $date_end   = '';
            if ( ! empty( $_GET['cdatestart'] )) {
                $time_start = strtotime( $_GET['cdatestart'] );
                $date_start = gmdate("Y-m-d", $time_start);
            }
            if ( ! empty( $_GET['cdateend'] )) {
                $time_end = strtotime( $_GET['cdateend'] );
                $date_end = gmdate("Y-m-d", $time_end);
            }
            
            $model = new IPTrank_Model();
            $this->items = $model->get_logs( $date_start, $date_end, $per_page, $page );

            $total_items = $model->get_found_item();
            $total_pages = ceil( $total_items / $per_page );
            $this->set_pagination_args( array(
                'total_items' => $total_items,
                'total_pages' => $total_pages,
                'per_page'    => $per_page
            ) );
        }

        /**
         * Get column no
         *
         * @param object $item
         * @return void
         */
        public function column_no( $item ) 
        {
            if ( ! isset( $this->log_number )) {
                $this->log_number = 0;
            }
            $this->log_number++;
            return $this->log_number;
        }

        /**
         * Get column date
         *
         * @param object $item
         * @return void
         */
        public function column_date( $item ) 
        {
            $date = mysql2date( 'd M y, h:i', $item->log_date );
            return $date;
        }

        /**
         * Get column action
         *
         * @param object $item
         * @return void
         */
        public function column_action( $item ) 
        {
            $action = $item->log_action;
            return $action;
        }

        /**
         * Get column description
         *
         * @param object $item
         * @return void
         */
        public function column_description( $item ) 
        {
            $desc = $item->log_desc;
            return $desc;
        }

        /**
         * Get column default
         *
         */
        public function column_default() 
        {
            return '';
        }
    }

}
?>