/**
 * Admin library 
 **/

(function($)
{
    //Text conf
    var delete_confirm_title = '';
    var delete_confirm_info  = '';
    if (typeof ip_ui_message.delete_confirm_title != 'undefined') {
        delete_confirm_title = ip_ui_message.delete_confirm_title;
    }
    if (typeof ip_ui_message.delete_confirm_info != 'undefined') {
        delete_confirm_info = ip_ui_message.delete_confirm_info;
    }
    
    //Prepare ui
    ip_ui.base.construct.prototype.image_base = iptrank_base + 'img/';
    ip_ui.base.confirm.prototype.set_ajax = function( ajax_url )
    {
        this.ajax_url = ajax_url;
    };
    ip_ui.init();
    ip_ui.delete_confirm = new ip_ui.base.confirm();
    
    ip_ui.delete_confirm.set_vars({
        title: delete_confirm_title,
        info: delete_confirm_info,
        yes_class:  'ipadm-btn ipadm-btn-danger',
        no_class:   'ipadm-btn ipadm-btn-default',
        action:     function( object, ui )
        {
            var id = object.attr( 'href' ).replace( '#toDelete_', '' );
            ip_ui.loader.show();
            ui.hide( object );
            
            $.ajax({
                url: ui.ajax_url + '&id='+id,
                type: "POST",
                dataType: "json",
                success: function (result) 
                {
                    if ( object.hasClass( 'iptrank-del-edit' ) )
                    {
                        window.location.href = result.redirect;
                    } else 
                    {
                        if ( result.status == '-1' ) {
                            ip_ui.message.modal( result.message, 'alert-danger' );
                        } else {
                            ip_ui.message.modal( result.message, 'alert-success' );
                            var tr = object.parents( 'tr' );
                            tr.hide( 'blind' );
                            setTimeout( function(){
                                tr.remove();
                            }, 600);
                        }
                        ip_ui.loader.hide();
                    }
                },
                error: function () {
                    alert( "Error in deleting item." );
                },
            });
        }
    });
    
    /**
     * Form handler
     */
    function ip_form( id ){
        this.form   = $( id );
        this.action = this.form.attr( 'action' );
    }
    //Set vars
    ip_form.prototype = 
    {
        //Variables
        button_id:          '.ip-form-submit',
        cont_id:            '.ip-form-cont',
        error_process:      'Error',
        success_process:    'Success',
        ajax_type:          'POST',
        ajax_dataType:      'json',
        
        //Init
        init: function()
        {
            var $this = this;
            //Prepare
            this.prepare();
            //Form submit
            $( this.button_id, $this.form ).click( function()
            {
                if ( $this.validator() ) {
                    if ( $this.before() ) {
                        ip_ui.loader.show();
                        var data   = $this.get_data();
                        var result = $this.process();
                        $this.after( result );
                    }
                }
                $this.error();
                return false;
            });
        },
        //Prepare form
        prepare: function(){},
        //Main process
        process: function()
        {
            var $this = this;
            var data  = $this.get_data();
            $.ajax({
                url: $this.action,
                type: $this.ajax_type,
                dataType: $this.ajax_dataType,
                data: data,
                success: function( result ) {
                    $this.ajax_success( result, $this );
                },
                error: function() {
                    $this.ajax_error( $this );
                }
            });
        },
        //Before process
        before: function()
        {
            return true;
        },
        //After process
        after: function( result ){},
        //Process if error
        error: function(){},
        //Process if ajax success
        ajax_success: function( result, $this )
        {
            $( '.ui-message', $this.form ).remove();
            ip_ui.loader.hide();
            if ( result.status == 1 ) {
                if ( typeof result.redirect != 'undefined' ) {
                    window.location.href = result.redirect;
                } else {
                    if ( typeof result.reset != 'undefined' ) {
                        $this.form[0].reset();
                    }
                    ip_ui.message.modal( result.message, 'alert-success' );
                }
            } else {
                ip_ui.message.modal( result.message, 'alert-danger' );
            }
        },
        //Process if ajax error
        ajax_error: function( $this )
        {
            ip_ui.loader.hide();
            ip_ui.message.modal( $this.error_process, 'alert-danger' );
        },
        
        //Validating form data
        validator: function()
        {
            return true;
        },
        check_empty: function( id, message )
        {
            var input = $( id );
            if ( input.val() == '' ) {
                ip_ui.message.block( message, 'ip-ui-danger', input );
                return true;
            }
            return false;
        },
        
        //Get data form
        get_data: function()
        {
            var root = this.form;
            var selector  = 'input[type=text]';
            selector += ', input[type=hidden]';
            selector += ', input[type=password]';
            selector += ', input[type=radio]:checked';
            selector += ', input[type=checkbox]:checked';
            selector += ', textarea';
            selector += ', select';
            
            var data = '';
            $( selector, root ).each( function(){
                var name  = $(this).attr( 'name' );
                var value = encodeURIComponent( $(this).val() );
                
                if ( data != '' ) {
                    data += '&';
                }
                data += name+'='+value;
            });
            if (typeof tinymce !== 'undefined') {
                for ( edId in tinymce.editors ) {
                    
                    if ( edId.length > 1 ) {
                        var value = tinymce.editors[edId].getContent();
                        if ( data != '' ) {
                            data += '&';
                        }
                        data += edId+'='+value;
                    }
                }
            }
            data = this.additional_data( data );
            return data;
        },
        additional_data: function( data )
        {
            return data;
        },
        
        //Get tiny mce object
        get_tinymce: function( contentId )
        {
            var content = '';
            if (typeof tinymce !== 'undefined') {
                content = tinyMCE.get( contentId ).getContent();
            }
            return content;
        },
        //Set tiny mce object with a content
        set_tinymce: function( contentId, content )
        {
            if (typeof tinymce !== 'undefined') {
                tinyMCE.get( contentId ).setContent( content );
            }
        }
    };
    window.ip_form = ip_form;
    
    /**
     * Modal link
     */
    $.fn.ip_modal = function()
    {
        $(this).each( function()
        {
            var link  = $(this);
            var href  = link.attr( 'href' );
            var popup = $( href );
            
            //Link close 
            $( '.ip-ui-close', popup ).click( function()
            {
                ip_ui.modal.popup_hide( popup );
                return false;
            });
            
            //Link open
            link.click( function()
            {
                ip_ui.modal.popup_show( popup );
                return false;
            });
        });
    };
    
})(jQuery);